@@ -7,7 +7,7 @@ from timeit import time
 from pdb import set_trace
 from optparse import OptionParser
 
-__version__ = '0.4.0'
+__version__ = '0.4.1'
 __author__ = 'Dane Springmeyer (dbsgeo [ -a- ] gmail.com)'
 __copyright__ = 'Copyright 2009, Dane Springmeyer'
 __license__ = 'GPLv2'
@@ -225,7 +225,7 @@ def make_list(option, opt, value, parser):
     
 
 parser.add_option('-f', '--format', dest='format',
-                  help='Format of image: png (32 bit), png256 (8 bit), jpeg, pdf, svg, ps, or all (will loop through all formats).')
+                  help='Format of image: png (32 bit), png256 (8 bit), jpeg, pdf, svg, ps, ARGB32, RGB24, or all (will loop through all formats).')
 
 parser.add_option('-c', '--center', dest='center', nargs=2,
                   help='Center coordinates. A long,lat pair e.g. -122.3 47.6 (Seattle)',
@@ -372,8 +372,8 @@ if __name__ == '__main__':
             if hasattr(options,'image'):
                 nik_map.open()
             else:
-                if not options.pipe:
-                    parser.error(color_text(4,'\n\nPlease provide the path to an out image.\n',options.no_color))
+                if not options.pipe and not options.dry_run:
+                    parser.error(color_text(4,'\n\nPlease provide the path to an output image.\n',options.no_color))
                 else:
                     nik_map.render()
     
